#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2021-12-18
#
# bakery plugin for check_mk
#

from pathlib import Path
from typing import List

from cmk.base.cee.plugins.bakery.bakery_api.v1 import FileGenerator, OS, Plugin, PluginConfig, register


def get_cve_2021_44228_log4j_files(conf: List[any]) -> FileGenerator:
    options = conf[1].copy()

    interval = options.get('interval', 86400)
    timeout = options.get('timeout', 300)
    search_path = options.get('search_path')

    drives_to_scan = options.get('drives_to_scan', '--all-drives')
    if drives_to_scan != '--all-drives':
        drives_to_scan = f'--drives {",".join(drives_to_scan)}'

    exclude_paths = ' --exclude '.join(options.get('exclude_paths', '')).strip(' ')
    if exclude_paths:
        exclude_paths = f' --exclude {exclude_paths}'

    exclude_fs = ','.join(options.get('exclude_fs', '')).strip(' ')
    if exclude_fs:
        exclude_fs = f'--exclude-fs {exclude_fs}'

    syslog = ''
    if options.get('syslog'):
        syslog_server = f'--syslog-udp {options["syslog"]["syslog_server"]}'
        syslog_level = f'--syslog-level {options["syslog"].get("syslog_level", "info")}'
        syslog_port = options['syslog'].get('syslog_port', None)
        if syslog_port is not None:
            syslog_port = f':{syslog_port}'
        else:
            syslog_port = ''
        syslog = f'{syslog_server}{syslog_port} {syslog_level}'

    reporting = ''
    if options.get('reporting'):
        report_dir = f'--report-dir {options["reporting"]["report_dir"]}'
        report_format = options['reporting'].get('report_format', '')
        no_empty_report = options['reporting'].get('no_empty_report', '')
        reporting = f' {report_dir} {report_format} {no_empty_report}'

    backup_dir = ''
    if options.get('fix_files'):
        backup_dir = f'--backup-path {options["fix_files"]["backup_dir"]}'
        if options['fix_files'].get('not_exclude_backup') is None:
            backup_dir += f' --exclude {options["fix_files"]["backup_dir"]}'
        backup_dir += f' {options["fix_files"].get("force_fix", "")}'

    for key in [
        'interval',
        'timeout',
        'search_path',
        'drives_to_scan',
        'exclude_paths',
        'exclude_fs',
        'syslog',
        'reporting',
        'fix_files',
    ]:
        try:
            options.pop(key)
        except KeyError:
            pass

    options = ' '.join(options.values())
    options = f'{options} {syslog} {reporting} {backup_dir} {exclude_paths} {exclude_fs}'.strip(' ')

    while '  ' in options:
        options = options.replace('  ', ' ')

    if conf[0] == 'linux':
        if search_path is None:
            search_path = '/'
        else:
            search_path = ' '.join(search_path)

        yield Plugin(
            base_os=OS.LINUX,
            source=Path('cve_2021_44228_log4j.linux'),
            target=Path('cve_2021_44228_log4j.sh'),
            asynchronous=True,
            interval=interval,
            timeout=timeout,
        )
        yield Plugin(
            base_os=OS.LINUX,
            source=Path('log4j2-scan.linux'),
            target=Path('../bin/log4j2-scan'),
        )

        yield PluginConfig(
            base_os=OS.LINUX,
            lines=[f'OPTIONS="{options} {search_path}"'],
            target=Path('cve_2021_44228_log4j.cfg'),
            include_header=True,
        )

    elif conf[0] == 'windows':
        if search_path is None:
            search_path = ''
        else:
            search_path = ' '.join(search_path)

        yield Plugin(
            base_os=OS.WINDOWS,
            source=Path('cve_2021_44228_log4j.windows'),
            target=Path('cve_2021_44228_log4j.ps1'),
            asynchronous=True,
            interval=interval,
            timeout=timeout,
        )
        yield Plugin(
            base_os=OS.WINDOWS,
            source=Path('log4j2-scan.windows'),
            target=Path('..\\bin\\log4j2-scan.exe'),
        )

        yield PluginConfig(
            base_os=OS.WINDOWS,
            lines=[f'OPTIONS="{options} {drives_to_scan} {search_path}"'],
            target=Path('cve_2021_44228_log4j.cfg'),
            include_header=True,
        )


register.bakery_plugin(
    name='cve_2021_44228_log4j',
    files_function=get_cve_2021_44228_log4j_files,
)
