#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2021-12-17
#
# Metrics file for the cve_2021_44228_log4j plugin
#
# 2021-12-20: added run time to the perfometer
#

from cmk.gui.i18n import _

from cmk.gui.plugins.metrics import (
    metric_info,
    graph_info,
    perfometer_info
)

metric_info['files_vulnerable'] = {
    'title': _('Vulnerable'),
    'unit': 'count',
    'color': '11/a',
}
metric_info['files_potential_vulnerable'] = {
    'title': _('Potentially vulnerable'),
    'unit': 'count',
    'color': '21/a',
}
metric_info['files_mitigated'] = {
    'title': _('Mitigated'),
    'unit': 'count',
    'color': '31/a',
}

metric_info['files_scanned'] = {
    'title': _('Files'),
    'unit': 'count',
    'color': '12/b',
}
metric_info['directories_scanned'] = {
    'title': _('Directories'),
    'unit': 'count',
    'color': '22/b',
}
metric_info['run_time'] = {
    'title': _('Run time'),
    'unit': 's',
    'color': '33/b',
}

graph_info['cve_2021_44228_log4j_found'] = {
    'title': _('Files found'),
    'metrics': [
        ('files_mitigated', '-stack'),
        ('files_potential_vulnerable', 'stack'),
        ('files_vulnerable', 'stack'),
    ],
    'scalars': [
        ('files_vulnerable:crit', _('crit')),
        ('files_vulnerable:warn', _('warn')),
    ],
}

graph_info['cve_2021_44228_log4j_scanned'] = {
    'title': _('Dirctories and files scanned'),
    'metrics': [
        ('directories_scanned', '-area'),
        ('files_scanned', 'area'),
    ],
}

graph_info['cve_2021_44228_log4j_runtime'] = {
    'title': _('Run time'),
    'metrics': [
        ('run_time', 'area'),
    ],
}

perfometer_info.append(('stacked', [
    {
        'type': 'linear',
        'segments': [
            'files_vulnerable',
            'files_potential_vulnerable',
            'files_mitigated',
        ],
        'total': 10,
    },
    {
        'type': 'linear',
        'segments': [
            'run_time',
        ],
        'total': 300,
    },
]))
